Returns a compact table describing raster dimensions, extent, CRS, resolution, layer names, and value range.
Arguments
- x
A raster-like object accepted by
as_bathy().
Examples
bathy_info(blueterra_example("bathy"))
#> # A tibble: 1 × 13
#> layer nrow ncol ncell xmin xmax ymin ymax xres yres min max
#> <chr> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl>
#> 1 bathy_m 90 190 17100 134960. 1.39e5 2.04e5 2.06e5 20.0 20.0 -427. -15.9
#> # ℹ 1 more variable: crs <chr>